weaviate.data
=============

.. automodule:: weaviate.data
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.data.references
------------------------

.. toctree::
   :maxdepth: 4

   weaviate.data.references
